@@ -14,7 +14,8 @@
 //! interface, it provides a `from_entropy` function which directly reads
 //! from the operating system entropy source. To preserve the
 //! capability-based interface, avoid using `rand::SeedableRng`'s
-//! `from_entropy` function on any of the types that implement that trait.
+//! `from_entropy` function on any of the types that implement that trait; use
+//! [`std_rng_from_entropy`] instead.
 //!
 //! [`OsRng`]: crate::rngs::OsRng
 //! [`CapRng`]: crate::rngs::CapRng
@@ -56,8 +57,8 @@ pub mod rngs {
     #[cfg(feature = "small_rng")]
     pub use rand::rngs::SmallRng;
 
-    /// A random number generator that retrieves randomness from from the
-    /// operating system.
+    /// A random number generator that retrieves randomness from the operating
+    /// system.
     ///
     /// This corresponds to [`rand::rngs::OsRng`], except instead of
     /// implementing `Default` it has an ambient-authority `default` function
@@ -73,7 +74,8 @@ pub mod rngs {
         /// This function makes use of ambient authority to access the platform
         /// entropy source.
         #[inline]
-        pub const fn default(_: AmbientAuthority) -> Self {
+        pub const fn default(ambient_authority: AmbientAuthority) -> Self {
+            let _ = ambient_authority;
             Self(())
         }
     }
@@ -160,12 +162,27 @@ pub mod rngs {
 /// This function makes use of ambient authority to access the platform entropy
 /// source.
 #[inline]
-pub fn thread_rng(_: AmbientAuthority) -> rngs::CapRng {
+pub fn thread_rng(ambient_authority: AmbientAuthority) -> rngs::CapRng {
+    let _ = ambient_authority;
     rngs::CapRng {
         inner: rand::thread_rng(),
     }
 }
 
+/// Retrieve the standard random number generator, seeded by the system.
+///
+/// This corresponds to [`rand::rngs::StdRng::from_entropy`].
+///
+/// # Ambient Authority
+///
+/// This function makes use of ambient authority to access the platform entropy
+/// source.
+#[inline]
+pub fn std_rng_from_entropy(ambient_authority: AmbientAuthority) -> rngs::StdRng {
+    let _ = ambient_authority;
+    rand::rngs::StdRng::from_entropy()
+}
+
 /// Generates a random value using the thread-local random number generator.
 ///
 /// This corresponds to [`rand::random`].
@@ -175,9 +192,10 @@ pub fn thread_rng(_: AmbientAuthority) -> rngs::CapRng {
 /// This function makes use of ambient authority to access the platform entropy
 /// source.
 #[inline]
-pub fn random<T>(_: AmbientAuthority) -> T
+pub fn random<T>(ambient_authority: AmbientAuthority) -> T
 where
     crate::distributions::Standard: crate::distributions::Distribution<T>,
 {
+    let _ = ambient_authority;
     rand::random()
 }
